@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import
 from .utils import AttributesDict
 
 from . import persistence
@@ -27,8 +28,7 @@ class ContextMixin(persistence.Savable):
             out_state[self.CONTEXT] = self._context.__dict__
 
     def load_instance_state(self, saved_state, load_context):
-        super(ContextMixin, self).load_instance_state(saved_state,
-                                                      load_context)
+        super(ContextMixin, self).load_instance_state(saved_state, load_context)
         try:
             self._context = AttributesDict(**saved_state[self.CONTEXT])
         except KeyError:
