@@ -1,4 +1,6 @@
 from __future__ import absolute_import
+
+import types
 from .utils import TestCase
 
 from plumpy.ports import InputPort, OutputPort, PortNamespace
@@ -25,6 +27,24 @@ class TestInputPort(TestCase):
         self.assertIsNone(port.validate(5))
         self.assertIsNotNone(port.validate(-5))
 
+    def test_lambda_default(self):
+        """Test a default with a lambda."""
+        from plumpy.ports import UNSPECIFIED
+
+        # The default should not be evaluated upon construction, so even if it will return an incorrect type, the
+        # following call should not fail
+        InputPort('lambda_default', default=lambda: 'string', valid_type=int)
+
+        port = InputPort('test', default=lambda: 5)
+
+        self.assertIsNone(port.validate(UNSPECIFIED))
+        self.assertIsNone(port.validate(3))
+
+        # Testing that passing an actual lambda as a value is alos possible
+        port = InputPort('test', valid_type=(types.FunctionType, int), default=lambda: 5)
+        some_lambda = lambda: 'string'
+        self.assertIsNone(port.validate(some_lambda))
+
 
 class TestOutputPort(TestCase):
 
@@ -74,14 +94,16 @@ class TestPortNamespace(TestCase):
         """Test validate method of a `PortNamespace`."""
 
         def validator(port_values):
-            if port_values['integer'] < 0:
+            if port_values['explicit'] < 0 or port_values['dynamic'] < 0:
                 return 'Only positive integers allowed'
 
+        self.port_namespace['explicit'] = InputPort('explicit', valid_type=int)
         self.port_namespace.validator = validator
         self.port_namespace.valid_type = int
 
-        self.assertIsNone(self.port_namespace.validate({'integer': 5}))
-        self.assertIsNotNone(self.port_namespace.validate({'integer': -5}))
+        # The explicit ports will be validated first before the namespace validator is called.
+        self.assertIsNone(self.port_namespace.validate({'explicit': 1, 'dynamic': 5}))
+        self.assertIsNotNone(self.port_namespace.validate({'dynamic': -5}))
 
     def test_port_namespace_dynamic(self):
         """
@@ -236,3 +258,22 @@ class TestPortNamespace(TestCase):
 
         # Because the namespace is lazy and no inputs were passed, the defaults should not have been populated.
         self.assertEqual(pre_processed, {})
+
+    def test_port_namespace_lambda_defaults(self):
+        """Verify that lambda defaults are accepted and properly evaluated."""
+        port_namespace = PortNamespace('base')
+        port_namespace['lambda_default'] = InputPort('lambda_default', default=lambda: 1, valid_type=(types.FunctionType, int))
+
+        inputs = port_namespace.pre_process({})
+        self.assertEqual(inputs['lambda_default'], 1)
+        self.assertIsNone(port_namespace.validate(inputs))
+
+        inputs = port_namespace.pre_process({'lambda_default': 5})
+        self.assertEqual(inputs['lambda_default'], 5)
+        self.assertIsNone(port_namespace.validate(inputs))
+
+        # When passing a lambda directly as the value, it should NOT be evaluated during pre_processing
+        some_lambda = lambda: 5
+        inputs = port_namespace.pre_process({'lambda_default': some_lambda})
+        self.assertEqual(inputs['lambda_default'], some_lambda)
+        self.assertIsNone(port_namespace.validate(inputs))
